@@ -132,19 +132,20 @@ static int write_adif_qsos(struct band *b, struct config_band *confb, FILE *f){
         }
         ADIF_STR   ("MODE",adif_modes[abs(q->mode)%10]); /* TODO sent vs rcvd */
         ADIF_STR_UC("RST_SENT",q->rsts);
-        ADIF_STR_UC("NO_SENT",q->qsonrs);
-        if (ctest->excused > 0 && ctest->qsoused == 0){
-            ADIF_STR_UC("STX",ctest->pexch);
-        }else{
+        if (ctest->excused > 0) {
+            ADIF_STR_UC("STX_STRING",ctest->pexch);
+        }
+        if (ctest->qsoused > 0){
             ADIF_STR_UC("STX",q->qsonrs);
         }
         ADIF_STR_UC("RST_RCVD",q->rstr);
-        if (ctest->excused > 0 && ctest->qsoused == 0){
-            ADIF_STR_UC("SRX",q->exc);
-        }else{
+        if (ctest->excused > 0) {
+            ADIF_STR_UC("SRX_STRING",q->exc);
+        }
+        if (ctest->qsoused > 0){
             ADIF_STR_UC("SRX",q->qsonrr);
         }
-        ADIF_STR_UC("NO_RCVD",q->qsonrr); 
+        ADIF_STR_UC("CONTEST_ID", ctest->tname);
         ADIF_STR_UC("GRIDSQUARE",q->locator);
         ADIF_INT   ("QRB", (int)q->qrb);
         ADIF_INT   ("QTF", q->qtf);
