@@ -700,7 +700,7 @@ int load_chart_from_file(gchar *filename){
 
     }
     fclose(f);
-    z_ptr_array_qsort(qrv->qrvs, qrv->sort);
+    //z_ptr_array_qsort(qrv->qrvs, qrv->sort);
     return 0;
 }
 
