@@ -174,8 +174,10 @@ void kst_qrv_sort(struct subwin *sw, struct event *ev){
 }
 
 int sw_kst_mouse_func(struct subwin *sw, struct event *ev, int fw){
-    struct menu_item *mi = NULL;
-    int y, items = 0, size;
+    //struct menu_item *mi = NULL;
+    int /*y, items = 0, */size;
+	struct timeval tv;
+	double ts;
     
     if (zselect_profiling(zsel)) zselect_hint(zsel, __FUNCTION__);
 
@@ -256,32 +258,34 @@ int sw_kst_mouse_func(struct subwin *sw, struct event *ev, int fw){
                 inputln_func(sw->il, ev);
                 return 1;
             }
-            g_free(sw->callunder);
-            sw->callunder = sw_kst_call_under(sw, ev->x - sw->x + sw->ho, ev->y - sw->y);
-            if (!sw->callunder) break;
-            mi = new_menu(1);
-            mi->rtext = sw->callunder;
-            if (!cfg->usetouch){
-                add_to_menu(&mi, CTEXT(T_MISTAKE), "", CTEXT(T_HK_MISTAKE), sw_kst_nothing, NULL, 0); items++;
-            }
-            add_to_menu(&mi, CTEXT(T_ASK_FOR_SKED), "", CTEXT(T_HK_ASK_FOR_SKED), sw_kst_ask_sked, GINT_TO_POINTER(1), 0); items++;
-            add_to_menu(&mi, CTEXT(T_ASK_FOR_SKED_B), "", CTEXT(T_HK_ASK_FOR_SKED_B), sw_kst_ask_sked, GINT_TO_POINTER(2), 0); items++;
-            add_to_menu(&mi, CTEXT(T_SELECT), "", CTEXT(T_HK_SELECT), sw_kst_select, NULL, 0); items++;
-            add_to_menu(&mi, CTEXT(T_HIDE),   "", CTEXT(T_HK_HIDE), sw_kst_hide, NULL, 0); items++;
-            add_to_menu(&mi, CTEXT(T_MESSAGE),   "", CTEXT(T_HK_MESSAGE), sw_kst_message, NULL, 0); items++;
-            add_to_menu(&mi, CTEXT(T_INFO),   "", CTEXT(T_HK_INFO), sw_kst_info, NULL, 0); items++;
-#ifdef Z_HAVE_SDL
-            if (gacs) {add_to_menu(&mi, CTEXT(T_AC_INFO),   "", CTEXT(T_HK_AC_INFO), sw_kst_ac_info, NULL, 0); items++;}
-#endif
-            if (aband) {
-                add_to_menu(&mi, CTEXT(T_USE),    "", CTEXT(T_HK_USE), sw_kst_use, NULL, 0);
-                items++;
-            }
-            y = ev->y - 1;
-            if (cfg->usetouch) y = ev->y - items - 1;
-            set_window_ptr(gses->win, ev->x - 3, y);
-            do_menu(mi, sw);
+			sw->callunderx = ev->x;
+			sw->callundery = ev->y;
+			gettimeofday(&tv, NULL);
+			ts = z_difftimeval_double(&tv, &sw->kst_latest_data);
+			if (ts < 1.0){
+				// moved
+				g_free(sw->callunder);
+				sw->callunder = NULL;
+				zg_ptr_array_free_all(sw->callsunder);
+				sw->callsunder = sw_kst_calls_under(sw, sw->h, ev->y - sw->y);
+				struct menu_item *mi = new_menu(3);
+				mi->rtext = "Choose call";
+				int i;
+				for (i = 0; i < sw->callsunder->len && i < sw->h; i++){
+					char *c = (char*)g_ptr_array_index(sw->callsunder, i);
+					add_to_menu(&mi, g_strdup(c), "", "", sw_kst_call_choosen, GINT_TO_POINTER(i), 0);
+				}
+				set_window_ptr(gses->win, ev->x - 3, ev->y);
+				do_menu(mi, sw);
+			}
+			else{
+				// steady
+				g_free(sw->callunder);
+				sw->callunder = sw_kst_call_under(sw, ev->x - sw->x + sw->ho, ev->y - sw->y);
 
+				if (!sw->callunder) break;
+				kst_right_mouse_2(sw, sw->callunder);
+			}
             break;
         case B_WHUP:
 /*            dbg("wheel up\n");*/
@@ -315,6 +319,42 @@ int sw_kst_mouse_func(struct subwin *sw, struct event *ev, int fw){
 }
 
 
+void sw_kst_call_choosen(void *itdata, void *menudata){
+	struct subwin *sw = (struct subwin *)menudata;
+	char *call = (char *)g_ptr_array_index(sw->callsunder, GPOINTER_TO_INT(itdata));
+	kst_right_mouse_2(sw, call);
+}
+
+
+void kst_right_mouse_2(struct subwin *sw, char *call){
+	int items = 0;
+	struct menu_item *mi = new_menu(1);
+	mi->rtext = call;
+	if (!cfg->usetouch){
+		add_to_menu(&mi, CTEXT(T_MISTAKE), "", CTEXT(T_HK_MISTAKE), sw_kst_nothing, NULL, 0); items++;
+	}
+	add_to_menu(&mi, CTEXT(T_ASK_FOR_SKED), "", CTEXT(T_HK_ASK_FOR_SKED), sw_kst_ask_sked, GINT_TO_POINTER(1), 0); items++;
+	add_to_menu(&mi, CTEXT(T_ASK_FOR_SKED_B), "", CTEXT(T_HK_ASK_FOR_SKED_B), sw_kst_ask_sked, GINT_TO_POINTER(2), 0); items++;
+	add_to_menu(&mi, CTEXT(T_SELECT), "", CTEXT(T_HK_SELECT), sw_kst_select, NULL, 0); items++;
+	add_to_menu(&mi, CTEXT(T_HIDE), "", CTEXT(T_HK_HIDE), sw_kst_hide, NULL, 0); items++;
+	add_to_menu(&mi, CTEXT(T_MESSAGE), "", CTEXT(T_HK_MESSAGE), sw_kst_message, NULL, 0); items++;
+	add_to_menu(&mi, CTEXT(T_INFO), "", CTEXT(T_HK_INFO), sw_kst_info, NULL, 0); items++;
+#ifdef Z_HAVE_SDL
+	if (gacs) { add_to_menu(&mi, CTEXT(T_AC_INFO), "", CTEXT(T_HK_AC_INFO), sw_kst_ac_info, NULL, 0); items++; }
+#endif
+	if (aband) {
+		add_to_menu(&mi, CTEXT(T_USE), "", CTEXT(T_HK_USE), sw_kst_use, NULL, 0);
+		items++;
+	}
+	int y = sw->callundery - 1;
+	if (cfg->usetouch) y = sw->callundery - items - 1;
+	set_window_ptr(gses->win, sw->callunderx - 3, y);
+	do_menu(mi, sw);
+
+
+}
+
+
 static void sw_kst_draw(gpointer key, gpointer value, gpointer user_data){
     //char raw[30];
     char *call = (char*)key;
@@ -711,6 +751,7 @@ void sw_kst_read_handler(void *xxx){
         sw->unread = 1;
         redraw_later();
     }
+	gettimeofday(&sw->kst_latest_data, NULL);
 
     if (!sw->chat) return;
     if (sw->lines->len <= 0) return;
@@ -1519,3 +1560,40 @@ x:;
     g_free(filename);
 }
 
+GPtrArray* sw_kst_calls_under(struct subwin *sw, int n, int y){
+	GPtrArray* ret = g_ptr_array_new();
+	int index = sw->lines->len - sw->offset - sw->h + y;
+	if (index >= sw->lines->len) index = sw->lines->len - 1;
+
+	for (; index >= 0 && n > 0; index--, n--){
+
+		char *b, *e;
+		dbg("i=%d\n", index);
+		char *orig = (char *)g_ptr_array_index(sw->lines, index);
+		char *line = z_str_uc(g_strdup(orig));
+		b = line;
+		while (*b != '\0'){
+			for (; *b != '\0' && !z_can_be_call_char(*b, ZCBC_MINUS); b++);
+			if (*b != '\0')
+			{
+				for (e = b; *e != '\0' && z_can_be_call_char(*e, ZCBC_MINUS); e++);
+				//if (*e == '\0') break; // while
+
+				*e = '\0';
+				if (regcmp(b, "^([0-9A-Z]{1,3}\\/)?([0-9][A-Z]|[A-Z]{1,2}[0-9]?)[0-9]{1,4}[A-Z]{1,4}(\\/[A-Z0-9]{1,3})*(-[0-9]{1,2})*$") == 0){
+				//if (z_can_be_call(b, ZCBC_MINUS)){
+
+					int eq = zg_ptr_array_find_str(ret, b);
+					if (eq == 1){
+						g_ptr_array_add(ret, g_strdup(b));
+						dbg("%s\n", b);
+					}
+				}
+				b = e + 1;
+			}
+		}
+		g_free(line);
+
+	}
+	return ret;
+}
