@@ -66,5 +66,9 @@ void kst_free_screen(struct subwin *sw);
 #endif
 void kst_open_bh(void *sw);
 void kst_dump_skip(void *x, void *menudata);
+GPtrArray* sw_kst_calls_under(struct subwin *sw, int n, int y);
+void kst_right_mouse_2(struct subwin *sw, char *call);
+void sw_kst_call_choosen(void *itdata, void *menudata);
+
 
 #endif
