@@ -18,17 +18,22 @@
 #include "rc.h"
 #include "tsdl.h"
 
-int rain_enable, rain_meteox, rain_wetteronline, rain_chmi, rain_debug;
+int rain_enable, rain_meteox, rain_wetteronline, rain_chmi, rain_weatheronline, rain_rainviewer, rain_debug;
 
 void refresh_rain_opts(void *arg){
     STORE_INT(cfg, rain_enable);
     STORE_INT(cfg, rain_meteox);
     STORE_INT(cfg, rain_wetteronline);
     STORE_INT(cfg, rain_chmi);
-    STORE_INT(cfg, rain_debug);
+    STORE_INT(cfg, rain_weatheronline);
+	STORE_INT(cfg, rain_rainviewer);
+	STORE_INT(cfg, rain_debug);
 
+
+#ifdef Z_HAVE_SDL    
 	free_rain(grain);
 	grain = init_rain();
+#endif
 	progress(NULL);
 }
 
@@ -40,6 +45,8 @@ void menu_rain_opts(void *itdata, void *menudata){
     LOAD_INT(cfg, rain_meteox);
     LOAD_INT(cfg, rain_wetteronline);
     LOAD_INT(cfg, rain_chmi);
+	LOAD_INT(cfg, rain_weatheronline);
+	LOAD_INT(cfg, rain_rainviewer);
     LOAD_INT(cfg, rain_debug);
 
     d = (struct dialog *)g_malloc(sizeof(struct dialog) + 20 * sizeof(struct dialog_item));
@@ -70,7 +77,7 @@ void menu_rain_opts(void *itdata, void *menudata){
     d->items[i].gnum = 1;
     d->items[i].dlen = sizeof(int);
     d->items[i].data = (char *)&rain_wetteronline;
-    d->items[i].msg = "Wetteronline";
+    d->items[i].msg = "Wetteronline (West EU)";
     d->items[i].wrap = 1;
 
     d->items[++i].type = D_CHECKBOX;      
@@ -79,12 +86,28 @@ void menu_rain_opts(void *itdata, void *menudata){
     d->items[i].dlen = sizeof(int);
     d->items[i].data = (char *)&rain_chmi;
     d->items[i].msg = "CHMI";
-    d->items[i].wrap = 2;
+    d->items[i].wrap = 1;
 
 	d->items[++i].type = D_CHECKBOX;      
     d->items[i].gid = 0;
     d->items[i].gnum = 1;
     d->items[i].dlen = sizeof(int);
+    d->items[i].data = (char *)&rain_weatheronline;
+    d->items[i].msg = "Weatheronline (EU)";
+    /*d->items[i].wrap = 1;
+
+	d->items[++i].type = D_CHECKBOX;
+	d->items[i].gid = 0;
+	d->items[i].gnum = 1;
+	d->items[i].dlen = sizeof(int);
+	d->items[i].data = (char *)&rain_rainviewer;
+	d->items[i].msg = "RainViewer.com (global)";*/
+	d->items[i].wrap = 2;
+
+	d->items[++i].type = D_CHECKBOX;
+    d->items[i].gid = 0;
+    d->items[i].gnum = 1;
+    d->items[i].dlen = sizeof(int);
     d->items[i].data = (char *)&rain_debug;
     d->items[i].msg = "Debug images";
     d->items[i].wrap = 1;
