@@ -225,7 +225,7 @@ enum ctrlstates{
     CTRL_SP = 1,        /* S&P, no TX */
     CTRL_REQR = 2,      /* RUN, TX    */
     CTRL_REQS = 3,      /* S&P, no TX */
-    CTRL_RUNING = 4,    /* S&P, TX    */
+    CTRL_RUNNING = 4,   /* S&P, TX    */
     CTRL_GIVEN = 5      /* RUN, no TX */
 };
 
