@@ -75,6 +75,7 @@ struct rain *init_rain(){
 	    provider->wmult = (provider->w2 - provider->w1) / (provider->wpx2 - provider->wpx1);
 
 		provider->hash_func = rain_meteox_hash;
+		provider->img2hw = rain_linear_img2hw;
 		for (i = 0; i < RAIN_COLORS; i++) provider->hashes[i] = g_hash_table_new(g_direct_hash, g_direct_equal);
 		provider->mask = 0xffffff80;
 		provider->step = 0x80;
@@ -111,6 +112,7 @@ struct rain *init_rain(){
 	    provider->wmult = (provider->w2 - provider->w1) / (provider->wpx2 - provider->wpx1);
 
 		provider->hash_func = rain_wetteronline_hash;
+		provider->img2hw = rain_linear_img2hw;
 		for (i = 0; i < RAIN_COLORS; i++) provider->hashes[i] = g_hash_table_new(g_direct_hash, g_direct_equal);
 		provider->mask = 0xffffff80;
 		provider->step = 0x80;
@@ -125,6 +127,8 @@ struct rain *init_rain(){
  		provider->translation = g_new0(int, provider->srccolslen);
 		for (i = 0; i < provider->srccolslen; i++) provider->translation[i] = i;
 
+		provider->ofs_min = -3; 
+
 		rain->wetteronline = provider;
 	}
 
@@ -145,6 +149,7 @@ struct rain *init_rain(){
 	    provider->wmult = (provider->w2 - provider->w1) / (provider->wpx2 - provider->wpx1);
 
 		provider->hash_func = rain_chmi_hash;
+		provider->img2hw = rain_linear_img2hw;
 		for (i = 0; i < RAIN_COLORS; i++) provider->hashes[i] = g_hash_table_new(g_direct_hash, g_direct_equal);
 		provider->mask = 0xffffff80;
 		provider->step = 0x80;
@@ -159,6 +164,40 @@ struct rain *init_rain(){
 		rain->chmi = provider;
 	}
 
+	if (cfg->rain_weatheronline){
+		struct rain_provider *provider = g_new0(struct rain_provider, 1);
+		provider->rain = rain;
+        provider->pal = rain->bwcolors;
+		provider->timer_id = zselect_timer_new(zsel, 1000, rain_weatheronline_timer, provider); 
+		provider->h1 = -5.6 * M_PI / 180.0; // lon
+		provider->h2 = 37.62 * M_PI / 180.0; // lon
+		provider->w1 = 35.96 * M_PI / 180.0;	 // lat
+		provider->w2 = 55.75 * M_PI / 180.0;  // lat
+		provider->hpx1 = 57;  // x
+		provider->hpx2 = 410; // x
+		provider->wpx1 = 438; // y
+		provider->wpx2 = 181; // y
+		provider->hmult = (provider->h2 - provider->h1) / (provider->hpx2 - provider->hpx1);
+	    provider->wmult = (provider->w2 - provider->w1) / (provider->wpx2 - provider->wpx1);
+
+		provider->hash_func = rain_weatheronline_hash;
+		provider->img2hw = rain_weatheronline_img2hw;
+		for (i = 0; i < RAIN_COLORS; i++) provider->hashes[i] = g_hash_table_new(g_direct_hash, g_direct_equal);
+		provider->mask = 0xffffff80;
+		provider->step = 0x80;
+
+		provider->left = 0;
+		provider->top = 0;
+		provider->right = 519;
+		provider->bottom = 550;
+
+		provider->srccolslen = 13;
+		provider->srccols = g_new0(int, provider->srccolslen);
+ 		provider->translation = g_new0(int, provider->srccolslen);
+		for (i = 0; i < provider->srccolslen; i++) provider->translation[i] = i;
+
+		rain->weatheronline = provider;
+	}
 	
     return rain;
 }
@@ -197,6 +236,7 @@ void free_rain(struct rain *rain){
 	if (rain->meteox) free_rain_provider(rain->meteox);
 	if (rain->wetteronline) free_rain_provider(rain->wetteronline);
 	if (rain->chmi) free_rain_provider(rain->chmi);
+	if (rain->weatheronline) free_rain_provider(rain->weatheronline);
 
     g_free(rain->colors);
     g_free(rain->bwcolors);
@@ -216,13 +256,11 @@ static void rain_provider_add(struct rain_provider *provider, int ix, int iy, in
 	struct zbinbuf *zbb;
 	struct rain_km km;
 
-	hh1 = provider->h1 + (ix - provider->hpx1) * provider->hmult;
-	ww1 = provider->w1 + (iy - provider->wpx1) * provider->wmult;
+    provider->img2hw(provider, ix, iy, &hh1, &ww1); 
+    provider->img2hw(provider, ix + 2, iy + 2, &hh2, &ww2);// when +1 space between bars 
 
-	//hh2 = provider->h1 + (ix + 1 - provider->hpx1) * provider->hmult;
-	//ww2 = provider->w1 + (iy + 1 - provider->wpx1) * provider->wmult;
-	hh2 = hh1 + provider->hmult;
-	ww2 = ww1 + provider->wmult;
+	//hh2 = hh1 + provider->hmult;
+	//ww2 = ww1 + provider->wmult;
 
 
 	hw2km_f(gses->myh, gses->myw, hh1, ww1, &km.kx1, &km.ky1);
@@ -271,6 +309,11 @@ void rain_provider_draw_colors(struct rain_provider *provider, SDL_Surface *surf
 	}
 }
 
+void rain_linear_img2hw(struct rain_provider *provider, int ix, int iy, double *h, double *w){
+	*h = provider->h1 + (ix - provider->hpx1) * provider->hmult;
+	*w = provider->w1 + (iy - provider->wpx1) * provider->wmult;
+}
+
 
 /* meteox.com */
 void rain_meteox_timer(void *arg){
@@ -425,7 +468,7 @@ void rain_meteox_load(struct rain_provider *provider){
                 ci = 14;
 			}
 			ci = provider->translation[ci];
-			if (ci == 0) continue;
+			if (ci < 5) continue;
             if (provider->rain->debug) z_putpixel_fmt(img, ix, iy, provider->rain->colors[ci], sdl->screen->format);
 			rain_provider_add(provider, ix, iy, ci);
 		}
@@ -457,11 +500,10 @@ void rain_wetteronline_timer(void *arg){
 	g_free(provider->title);
 	provider->title = g_strdup_printf("WtOnl. %02d:%02dZ", tm.tm_hour, tm.tm_min);
 
-    url = g_strdup_printf("http://www.wetteronline.de/?pid=p_radar_map&ireq=true&src=wmapsextract/vermarktung/prog2maps/short_range/%04d/%02d/%02d/0001/grey_flat/%04d%02d%02d%02d%02d_0001.png", 
+    url = g_strdup_printf("http://tucnak.vaiz.cz/wetteronline.php?y=%d&m=%d&d=%d&h=%d&mi=%d&t=%lld", 
         tm.tm_year + 1900, tm.tm_mon + 1, tm.tm_mday,
-        tm.tm_year + 1900, tm.tm_mon + 1, tm.tm_mday,
-        tm.tm_hour, tm.tm_min); 
-    //url = g_strdup("http://www.wetteronline.de/?pid=p_radar_map&ireq=true&src=wmapsextract/vermarktung/prog2maps/short_range/2016/07/08/0001/grey_flat/201607081800_0001.png");
+		tm.tm_hour, tm.tm_min, tl); 
+	//url = g_strdup("https://www.wetteronline.de/?ireq=true&pid=p_radar_map&src=wmapsextract/vermarktung/global2maps/2018/08/02/0001/grey_flat/201808020730_0001.png");
 
     provider->http = zhttp_init();
     dbg("wetteronline url = '%s'\n", url);
@@ -553,6 +595,8 @@ void rain_wetteronline_load(struct rain_provider *provider){
 			for (ci = 0; ci < provider->srccolslen; ci++){
 				if (c == provider->srccols[ci]){
 					ci = provider->translation[ci];
+					if (ci < 5) break;
+
 					rain_provider_add(provider, ix, iy, ci);
 					if (provider->rain->debug) z_putpixel_fmt(img, ix, iy, provider->rain->colors[ci], sdl->screen->format); 
 					break;
@@ -674,7 +718,7 @@ void rain_chmi_load(struct rain_provider *provider){
 			} 
 			for (ci = 0; ci < RAIN_COLORS; ci++){
 				if (c == provider->rain->colors[ci]){
-					if (ci == 0) break;
+					if (ci < 5) break;
 					rain_provider_add(provider, ix, iy, ci);
 					break;
 				}
@@ -690,4 +734,226 @@ gpointer rain_chmi_hash(short kx, short ky, int ci){
 	return GUINT_TO_POINTER(key); 
 }
 
+
+/* weatheronline.co.uk */
+void rain_weatheronline_timer(void *arg){
+    char *url;
+    time_t tt;
+    struct tm tm;
+    struct rain_provider *provider = (struct rain_provider*)arg;
+
+    tt = time(NULL);
+	tt = ((tt + 1800) / 3600) * 3600;
+    gmtime_r(&tt, &tm);
+
+	g_free(provider->title);
+	provider->title = g_strdup_printf("WO-EU. %02d:%02dZ", tm.tm_hour, tm.tm_min);
+
+    url = g_strdup(/*"http://maps.nagano.cz/weatheronline_cal3.png"*/ "http://maps.vaiz.cz/eueu.php");
+
+    provider->http = zhttp_init();
+    dbg("weatheronline url = '%s'\n", url);
+    zhttp_get(provider->http, zsel, url, rain_weatheronline_downloaded, provider);
+    g_free(url);
+	provider->timer_id = zselect_timer_new(zsel, 50*1000, rain_weatheronline_timer, provider); // restart when freezes
+}
+
+void rain_weatheronline_downloaded(struct zhttp *http){
+    int remains;
+    struct timeval tv;
+    struct rain_provider *provider = (struct rain_provider*)http->arg;
+    SDL_Surface *newimg;
+    
+    if (provider->timer_id) {
+        zselect_timer_kill(zsel, provider->timer_id);
+        provider->timer_id = 0;
+    }
+	
+	if (provider->rain->debug) zbinbuf_write_to_file(http->response, "_weatheronline.png", http->dataofs, http->response->len - http->dataofs);
+
+    newimg = zpng_create(http->response->buf + http->dataofs, http->response->len - http->dataofs);
+    if (newimg == NULL){
+        dbg("Can't read bitmap\n");
+        provider->pal = provider->rain->bwcolors;
+		provider->timer_id = zselect_timer_new(zsel, 1 * 60 * 1000, rain_weatheronline_timer, provider);
+    }else{
+        if (provider->img != NULL) {
+            SDL_FreeSurface(provider->img);
+        }
+        provider->img = newimg;
+        provider->pal = provider->rain->colors;
+        rain_weatheronline_load(provider);
+		if (provider->rain->debug) {
+			rain_provider_draw_colors(provider, provider->img);
+			zpng_save(provider->img, "_weatheronline2.png", NULL);
+		}
+
+		//provider->timer_id = zselect_timer_new(zsel, 1 * 60 * 1000, rain_weatheronline_timer, provider);
+	    gettimeofday(&tv, NULL);
+    	remains = 300000 - ((tv.tv_sec % 300) * 1000 + tv.tv_usec/1000) + 500;
+	    provider->timer_id = zselect_timer_new(zsel, remains, rain_weatheronline_timer, provider);
+    }
+	zhttp_free(http);
+	provider->http = NULL;
+	sw_set_gdirty(SWT_MAP);
+
+    //ST_STOP("rain_downloaded");
+}
+
+// colors are in image format
+void rain_weatheronline_load(struct rain_provider *provider){
+	int ix, iy, c, ci, i;
+	SDL_Surface *img = provider->img;
+	
+	provider->srccols[0] = (int)SDL_MapRGB(img->format,  250, 250, 243); // 0-0.25 mm/h
+	//provider->srccols[0] = (int)SDL_MapRGB(img->format,  148, 148, 148); // calibration test
+	provider->srccols[1] = (int)SDL_MapRGB(img->format,  252, 255, 193); // 0.25-1 
+	provider->srccols[2] = (int)SDL_MapRGB(img->format,  251, 255,  92); // 1-2
+	provider->srccols[3] = (int)SDL_MapRGB(img->format,  160, 214,  38); // 2-5
+	provider->srccols[4] = (int)SDL_MapRGB(img->format,   69, 195, 121); // 5-10
+	provider->srccols[5] = (int)SDL_MapRGB(img->format,    0, 214, 216); // 10-15
+	provider->srccols[6] = (int)SDL_MapRGB(img->format,   17, 161, 214); // 15-20
+	provider->srccols[7] = (int)SDL_MapRGB(img->format,    9, 50,  253); // 20-30
+	provider->srccols[8] = (int)SDL_MapRGB(img->format,  164,  77, 196); // 30-50
+	provider->srccols[9] = (int)SDL_MapRGB(img->format,  228,  75, 209); // 50-80
+	provider->srccols[10] = (int)SDL_MapRGB(img->format, 238,  39,   8); // 80-100
+	provider->srccols[11] = (int)SDL_MapRGB(img->format, 156,  28,  13); // 100-150
+	provider->srccols[12] = (int)SDL_MapRGB(img->format,  99,  21,  14); // 150-inf.
+
+	provider->translation[0] = 3;
+	provider->translation[1] = 4;
+	provider->translation[2] = 5; // 1 mm/h
+	provider->translation[3] = 6;
+	provider->translation[4] = 8;
+	provider->translation[5] = 9; // 10 mm/h
+	provider->translation[6] = 10;
+	provider->translation[7] = 10;
+	provider->translation[8] = 11;
+	provider->translation[9] = 12;
+	provider->translation[10] =	12;
+	provider->translation[11] = 13; // 100 mm/h
+	provider->translation[12] =	14;
+	
+	provider->w = img->w;
+	provider->h = img->h;
+	
+	for (i = 0; i < RAIN_COLORS; i++) {
+		GHashTable *hash = provider->hashes[i];
+		g_hash_table_foreach(hash, rain_truncate_hash, NULL);
+	}
+
+    for (iy = provider->top; iy < img->h && iy <= provider->bottom; iy++){
+        for (ix = provider->left; ix < img->w && ix <= provider->right; ix++){
+			Uint8 r, g, b;
+            int found = 0;
+
+			c = z_getpixel(img, ix, iy);
+			/*if (ix == 60 && iy == 60){
+				int a =0 ;
+			} */
+			
+            i = 0;
+            do {
+				SDL_GetRGB(c, img->format, &r, &g, &b);
+                if (ix + i < 0) break;
+                if (i < -10) break;
+                i--;
+				c = z_getpixel(img, ix + i, iy);
+				SDL_GetRGB(c, img->format, &r, &g, &b);
+            } while (r <= 57 && (r == g && r == b && g == b));
+			/*for (i = -1; i > -10 && ix + i >= 0; i--){
+				c = z_getpixel(img, ix + i, iy);
+				SDL_GetRGB(c, img->format, &r, &g, &b);
+				if (r >= 28 || g >= 51 || b >= 153) break;
+			}*/ 
+			
+			for (ci = 0; ci < provider->srccolslen; ci++){
+				if (c == provider->srccols[ci]){
+                    found = 1;
+					ci = provider->translation[ci];
+					if (ci < 5) break;
+
+					rain_provider_add(provider, ix, iy, ci);
+					if (provider->rain->debug) z_putpixel_fmt(img, ix, iy, provider->rain->colors[ci], sdl->screen->format); 
+					break;
+				}
+			}
+            if (!found){
+                int r = z_r(img, c);
+                int g = z_g(img, c);
+                int b = z_b(img, c);
+                if (r == g && g == b && b == r) continue;
+                if (r == 0 && g == 0 && b == 0) continue;
+                if (r == 57 && g == 57 && b == 57) continue;
+                if (r == 148 && g == 148 && b == 147) continue;
+                if (r == 148 && g == 148 && b == 148) continue;
+                if (r == 129 && g == 129 && b == 129) continue;
+                if (r == 200 && g == 200 && b == 200) continue;
+                dbg("unknown color at [%d,%d] = %d, %d, %d\n", ix, iy, r, g, b);
+            }
+		}
+	}
+}
+
+gpointer rain_weatheronline_hash(short kx, short ky, int ci){
+	unsigned int key = ((unsigned short)kx) >> 7;
+	key |= (((unsigned short)ky) >> 1) & 0xff00;
+	key |= ((unsigned char)ci) << 16; 
+	return GUINT_TO_POINTER(key); 
+}
+
+
+void rain_weatheronline_img2hw(struct rain_provider *provider, int ix, int iy, double *h, double *w){
+	double dx = ix - 234;
+	double dy = iy + 280;
+	double d = sqrt(dx * dx + dy * dy) / 12.6 - 4.75;
+	double a = atan2(dy, dx);
+	*w = 90 - d;
+	*h = 90 - (a * 180 / M_PI) + 9.5;
+	*h *= 27.5 / 22.0;
+
+	*w *= M_PI / 180.0;
+	*h *= M_PI / 180.0;
+}
+
+/* www.rainviewer.com */
+int tile_googlezoom(int size, double dh, double dw, int px, int py)
+{
+	double hexp, wexp, gzh, gzw;
+	int gz;
+
+	hexp = 2 * M_PI / fabs(dh);
+	if (hexp < 2.0)
+		gzh = 0;
+	else
+		gzh = log(hexp) / log(2);
+	dbg("hexp=%4.2f  gzh=%4.2f \n", hexp, gzh);
+
+	wexp = M_PI / fabs(dw);
+	if (wexp < 2.0)
+		gzw = 0;
+	else
+		gzw = log(wexp) / log(2);
+	dbg("wexp=%4.2f  gzw=%4.2f \n", wexp, gzw);
+
+	gz = (int)(Z_MAX(gzw, gzh));
+	dbg("gz=%d\n", gz);
+
+	return (int)gz;
+}
+
+void tile_get_hwi(int gz, double h, double w, int *hi, int *wi){
+
+	if (h < 0.0 || h >= 360) *hi = -1;
+	if (w < 0.0 || w >= 180) *hi = -1;
+
+	*hi = (int)((h + 180.0) * (1 << gz) / 360.0);
+	*wi = (int)((90.0 - w) * (1 << gz) / 360.0);
+}
+
+
+
+
+
+
 #endif
