@@ -58,13 +58,13 @@ struct ssbd *init_ssbd(){
 #if defined(Z_HAVE_SDL) && defined(Z_HAVE_LIBPNG)    
     if (sdl){
         ssbd->norecicon = zpng_create(icon_norec, sizeof(icon_norec));
-        if (!ssbd->norecicon) zinternal("Can't create norec icon, currupted executable?");
+        if (!ssbd->norecicon) zinternal("Can't create norec icon, corrupted executable?");
     
         ssbd->recicon = zpng_create(icon_record, sizeof(icon_record));
-        if (!ssbd->recicon) zinternal("Can't create record icon, currupted executable?");
+        if (!ssbd->recicon) zinternal("Can't create record icon, corrupted executable?");
     
         ssbd->playicon = zpng_create(icon_play, sizeof(icon_play));
-        if (!ssbd->playicon) zinternal("Can't create play icon, currupted executable?");
+        if (!ssbd->playicon) zinternal("Can't create play icon, corrupted executable?");
     }
 #endif
     ssbd->loglevel = -1;
