@@ -395,6 +395,9 @@ void update_stats(struct band *band, struct stats *st, struct qso *q){
             break;
 		case 20: /* WWL ring Contest Lombardia */
 			qsop = (qsopwr(ctest->pwwlo, q->locator) - 1) * ctest->qsomult * band->qsomultb;
+        case 21: // R-Contest
+          qsop = 1;
+        break;
 			break;
 
     }
