@@ -394,6 +394,7 @@ struct subwin *new_subwin(enum sw_type type, int where_){
     	
 			}
 			sw_add_line(sw, VTEXT(T_ENTER_TO_KST), 1);
+			gettimeofday(&sw->kst_latest_data, NULL);
 			break;
 		case SWT_SDR:
             sw->title = g_strdup(VTEXT(T_SDR));
@@ -491,6 +492,7 @@ void free_subwin(struct subwin *sw){
 	if (sw->adns) zasyncdns_free(sw->adns);
 	if (sw->kstusers) g_hash_table_remove_all(sw->kstusers);
 	g_free(sw->callunder);
+	zg_ptr_array_free_all(sw->callsunder);
 	g_free(sw->pattern);
 	g_free(sw->player_filename);
     g_free(sw);
@@ -2489,7 +2491,7 @@ void sw_highlight(struct subwin *sw, const char *text, const char *needle, int c
     while ((d = z_strcasestr(cc, needle)) != NULL){ 
 		if (whole){
 			if (d > cc){
-				char before = d[-1];
+				int before = d[-1];
 				if (isalnum(before)) {
 					cc = d + strlen(needle); 
 					continue;
