@@ -44,6 +44,7 @@ struct zzsdl *zsdl;
 
 SDL_Color pal[256];
 
+
 #ifdef SDLTEST
 int sdl_test(void);
 #endif
@@ -140,13 +141,13 @@ struct tsdl *init_sdl(){
 	sdl->key = zpng_create(icon_key32, sizeof(icon_key32));
 	sdl->xfer = zpng_create(icon_xfer32, sizeof(icon_xfer32));
 
-    if (!sdl->icon) zinternal("Can't create icon_tucnak, currupted executable?");
-    if (!tucnak64) zinternal("Can't create icon_tucnak64, currupted executable?");
-    if (!sdl->home) zinternal("Can't create icon_home32, currupted executable?");
-    if (!sdl->zoomin) zinternal("Can't create icon_zoomin32, currupted executable?");
-    if (!sdl->zoomout) zinternal("Can't create icon_zoomout32, currupted executable?");
-    if (!sdl->key) zinternal("Can't create icon_key, currupted executable?");
-    if (!sdl->xfer) zinternal("Can't create icon_xfer, currupted executable?");
+    if (!sdl->icon) zinternal("Can't create icon_tucnak, corrupted executable?");
+    if (!tucnak64) zinternal("Can't create icon_tucnak64, corrupted executable?");
+    if (!sdl->home) zinternal("Can't create icon_home32, corrupted executable?");
+    if (!sdl->zoomin) zinternal("Can't create icon_zoomin32, corrupted executable?");
+    if (!sdl->zoomout) zinternal("Can't create icon_zoomout32, corrupted executable?");
+    if (!sdl->key) zinternal("Can't create icon_key, corrupted executable?");
+    if (!sdl->xfer) zinternal("Can't create icon_xfer, corrupted executable?");
     SDL_WM_SetIcon(sdl->icon, NULL);
 #endif
 	if (z_pipe(sdl->eventpipe)) {
@@ -234,7 +235,7 @@ void sdl_stop_event_thread(){
 
 void free_sdl(){
     if (!sdl) return;
-#ifdef Z_MSC_MINGW
+#ifdef EVENTS_IN_SAME_THREAD
 	if (sdl->event_timer_id) zselect_timer_kill(zsel, sdl->event_timer_id);
 #endif
 
@@ -322,7 +323,7 @@ void sdl_info(GString *gs){
 }
 
 
-#ifdef Z_MSC_MINGW
+#ifdef EVENTS_IN_SAME_THREAD
 void sdl_event_timer(void *xxx){
 	if (!sdl) return;
 	SDL_PumpEvents();
@@ -447,7 +448,7 @@ int sdl_setvideomode(int w, int h, int init_x){
 	SDL_UpdateRect(sdl->screen, 0, 0, sdl->screen->w, sdl->screen->h); // fill space between char area and screen boundary
 	//sleep(3);
     
-#ifdef Z_MSC_MINGW
+#ifdef EVENTS_IN_SAME_THREAD
 	if (!sdl->event_timer_id) sdl->event_timer_id = zselect_timer_new(zsel, 100, sdl_event_timer, NULL);
 #endif
     return 0;
@@ -828,7 +829,7 @@ gpointer sdl_event_thread(gpointer handle){
 #endif                
         ev.ev = ev.x = ev.y = ev.b = 0;
         k=sk=0;
-#ifndef Z_MSC_MINGW
+#ifndef EVENTS_IN_SAME_THREAD
 		SDL_PumpEvents();
 #endif
 		switch(SDL_PeepEvents(&sev, 1, SDL_GETEVENT, SDL_ALLEVENTS)) {
@@ -959,6 +960,7 @@ gpointer sdl_event_thread(gpointer handle){
                     case SDLK_KP_MULTIPLY: 	k=sk='*';            goto handle;
                     case SDLK_KP_MINUS: 	k=sk='-';            goto handle;
                     case SDLK_KP_PLUS: 	    k=sk='+';            goto handle;
+					case SDLK_BACKQUOTE:    k = '`'; sk = '~';   goto handle;
                     default: break;
                 }
 
@@ -996,7 +998,7 @@ gpointer sdl_event_thread(gpointer handle){
                     case SDLK_LEFTBRACKET:  k='[';   sk='{';     break;
                     case SDLK_BACKSLASH:    k='\\';  sk='|';     break;
                     case SDLK_RIGHTBRACKET: k=']';   sk='}';     break;
-                    case SDLK_BACKQUOTE:    k='`';   sk='~';     break;
+                    //case SDLK_BACKQUOTE:    k='`';   sk='~';     break;
                     case SDLK_AT:           k='@';   sk='2';     break;
                                                           
                     default: 
